@@ -376,7 +376,16 @@ extern void e_marshal_VOID__POINTER_INT_INT_INT (GClosure     *closure,
                                                  gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_INT_INT_INT	e_marshal_VOID__POINTER_INT_INT_INT
 
-/* NONE:POINTER,POINTER (e-marshal.list:47) */
+/* NONE:POINTER,INT,OBJECT (e-marshal.list:47) */
+extern void e_marshal_VOID__POINTER_INT_OBJECT (GClosure     *closure,
+                                                GValue       *return_value,
+                                                guint         n_param_values,
+                                                const GValue *param_values,
+                                                gpointer      invocation_hint,
+                                                gpointer      marshal_data);
+#define e_marshal_NONE__POINTER_INT_OBJECT	e_marshal_VOID__POINTER_INT_OBJECT
+
+/* NONE:POINTER,POINTER (e-marshal.list:48) */
 extern void e_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -385,7 +394,7 @@ extern void e_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                              gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_POINTER	e_marshal_VOID__POINTER_POINTER
 
-/* NONE:POINTER,POINTER,INT (e-marshal.list:48) */
+/* NONE:POINTER,POINTER,INT (e-marshal.list:49) */
 extern void e_marshal_VOID__POINTER_POINTER_INT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -394,7 +403,7 @@ extern void e_marshal_VOID__POINTER_POINTER_INT (GClosure     *closure,
                                                  gpointer      marshal_data);
 #define e_marshal_NONE__POINTER_POINTER_INT	e_marshal_VOID__POINTER_POINTER_INT
 
-/* OBJECT:OBJECT,DOUBLE,DOUBLE,BOOLEAN (e-marshal.list:49) */
+/* OBJECT:OBJECT,DOUBLE,DOUBLE,BOOLEAN (e-marshal.list:50) */
 extern void e_marshal_OBJECT__OBJECT_DOUBLE_DOUBLE_BOOLEAN (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
@@ -402,7 +411,7 @@ extern void e_marshal_OBJECT__OBJECT_DOUBLE_DOUBLE_BOOLEAN (GClosure     *closur
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);
 
-/* POINTER:NONE (e-marshal.list:50) */
+/* POINTER:NONE (e-marshal.list:51) */
 extern void e_marshal_POINTER__VOID (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
